package Acme::Version::Same;

use 5.006;
use strict;
use warnings;

=head1 NAME

Acme::Version::Same - Module for testing CPAN Pause indexing

=head1 VERSION

Version 0.01

=cut

our $VERSION = '0.01';


=head1 SYNOPSIS

Quick summary of what the module does.

Perhaps a little code snippet.

    use Acme::Version::Same;

    my $foo = Acme::Version::Same->new();
    ...

=head1 EXPORT

A list of functions that can be exported.  You can delete this section
if you don't export anything, such as for a purely object-oriented module.

=head1 SUBROUTINES/METHODS

=head2 function1

=cut

sub function1 {
}

=head2 function2

=cut

sub function2 {
}

=head1 AUTHOR

Thibault Duponchelle, C<< <thibault.duponchelle at gmail.com> >>

=head1 BUGS

Please report any bugs or feature requests to C<bug-acme-version-same at rt.cpan.org>, or through
the web interface at L<https://rt.cpan.org/NoAuth/ReportBug.html?Queue=Acme-Version-Same>.  I will be notified, and then you'll
automatically be notified of progress on your bug as I make changes.




=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Acme::Version::Same


You can also look for information at:

=over 4

=item * RT: CPAN's request tracker (report bugs here)

L<https://rt.cpan.org/NoAuth/Bugs.html?Dist=Acme-Version-Same>

=item * CPAN Ratings

L<https://cpanratings.perl.org/d/Acme-Version-Same>

=item * Search CPAN

L<https://metacpan.org/release/Acme-Version-Same>

=back


=head1 ACKNOWLEDGEMENTS


=head1 LICENSE AND COPYRIGHT

This software is Copyright (c) 2024 by Thibault Duponchelle.

This is free software, licensed under:

  The Artistic License 2.0 (GPL Compatible)


=cut

1; # End of Acme::Version::Same
